(defun vm-its-such-a-cruel-world ()
   (require 'vm-version)
   (require 'vm-startup)
   (require 'vm-vars)
   (require 'vm-autoload))
(vm-its-such-a-cruel-world)
(fmakunbound 'vm-its-such-a-cruel-world)
